@@ -278,6 +278,9 @@ static const gnutls_error_entry error_algorithms[] = {
   ERROR_ENTRY (N_("Error interfacing with /dev/crypto"),
 	       GNUTLS_E_CRYPTODEV_IOCTL_ERROR, 1),
 
+  ERROR_ENTRY (N_("Channel binding data not available"),
+	       GNUTLS_E_CHANNEL_BINDING_NOT_AVAILABLE, 1),
+
   ERROR_ENTRY (N_("PKCS #11 error."),
 	       GNUTLS_E_PKCS11_ERROR, 1),
   ERROR_ENTRY (N_("PKCS #11 initialization error."),
