@@ -281,7 +281,8 @@ _gnutls_x509_parse_dn (ASN1_TYPE asn1_struct,
 	      gnutls_assert ();
 	      _gnutls_x509_log
 		("Found OID: '%s' with value '%s'\n",
-		 oid, _gnutls_bin2hex (value2, len, escaped, sizeof_escaped, NULL));
+		 oid, _gnutls_bin2hex (value2, len, escaped, sizeof_escaped,
+				       NULL));
 	      goto cleanup;
 	    }
 	  STR_APPEND (str_escape (string, escaped, sizeof_escaped));
@@ -655,7 +656,7 @@ _gnutls_x509_encode_and_write_attribute (const char *given_oid,
 
   /* Find how to encode the data.
    */
-  val_name = _gnutls_x509_oid2asn_string(given_oid);
+  val_name = _gnutls_x509_oid2asn_string (given_oid);
   if (val_name == NULL)
     {
       gnutls_assert ();
