@@ -493,7 +493,8 @@ print_info (gnutls_session_t session, const char *hostname, int insecure)
       gnutls_datum cb;
       int rc;
 
-      rc = gnutls_session_channel_binding (session, GNUTLS_CB_TLS_UNIQUE, &cb);
+      rc =
+	gnutls_session_channel_binding (session, GNUTLS_CB_TLS_UNIQUE, &cb);
       if (rc)
 	fprintf (stderr, "Channel binding error: %s\n", gnutls_strerror (rc));
       else
