@@ -1,19 +1,23 @@
 #ifndef P11TOOL_H
-# define P11TOOL_H
+#define P11TOOL_H
 
 #include "certtool-common.h"
 
 void pkcs11_list (FILE * outfile, const char *url, int type,
-		  unsigned int login, unsigned int detailed, common_info_st*);
-void pkcs11_mechanism_list (FILE * outfile, const char *url, unsigned int login, common_info_st*);
+		  unsigned int login, unsigned int detailed,
+		  common_info_st *);
+void pkcs11_mechanism_list (FILE * outfile, const char *url,
+			    unsigned int login, common_info_st *);
 void pkcs11_export (FILE * outfile, const char *pkcs11_url,
-		    unsigned int login, common_info_st*);
-void pkcs11_token_list (FILE * outfile, unsigned int detailed, common_info_st*);
+		    unsigned int login, common_info_st *);
+void pkcs11_token_list (FILE * outfile, unsigned int detailed,
+			common_info_st *);
 void pkcs11_write (FILE * outfile, const char *pkcs11_url, const char *label,
-		   int trusted, unsigned int login, common_info_st*);
+		   int trusted, unsigned int login, common_info_st *);
 void pkcs11_delete (FILE * outfile, const char *pkcs11_url, int batch,
-		    unsigned int login, common_info_st*);
-void pkcs11_init (FILE * outfile, const char *pkcs11_url, const char* label, common_info_st*);
+		    unsigned int login, common_info_st *);
+void pkcs11_init (FILE * outfile, const char *pkcs11_url, const char *label,
+		  common_info_st *);
 
 #define PKCS11_TYPE_CRT_ALL 1
 #define PKCS11_TYPE_TRUSTED 2
