@@ -29,7 +29,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -295,11 +295,11 @@ main (int argc, char *argv[])
 	}
     }
   while (
-	 /* Not done: */
-	 !(sret == GNUTLS_E_AGAIN
-	   && cret == GNUTLS_E_UNSAFE_RENEGOTIATION_DENIED)
-	 /* No error: */
-	 && (cret == GNUTLS_E_AGAIN || sret == GNUTLS_E_AGAIN));
+	  /* Not done: */
+	  !(sret == GNUTLS_E_AGAIN
+	    && cret == GNUTLS_E_UNSAFE_RENEGOTIATION_DENIED)
+	  /* No error: */
+	  && (cret == GNUTLS_E_AGAIN || sret == GNUTLS_E_AGAIN));
 
   if (sret != GNUTLS_E_AGAIN && cret != GNUTLS_E_UNSAFE_RENEGOTIATION_DENIED)
     exit_code = 1;
@@ -307,7 +307,8 @@ main (int argc, char *argv[])
   if (gnutls_safe_renegotiation_status (client) ||
       gnutls_safe_renegotiation_status (server))
     {
-      tls_log_func (0, "Rehandshaked session not using safe renegotiation!\n");
+      tls_log_func (0,
+		    "Rehandshaked session not using safe renegotiation!\n");
       exit_code = EXIT_FAILURE;
     }
 
